Merging — Open Contracting Data Standard 1.1.5 documentation

# Merging

An OCDS record …

## Merging specification

### Merge routine

To create a compiled or versioned release, you must:

1. Get all releases with the same `ocid` value

#### Array values

If the input array contains anything other than objects, treat the array as a literal value. Otherwise, there are two sub-routines for arrays of objects: whole list merge and identifier merge.

##### Whole list merge

An input array must be treated as a literal value if the corresponding field in a dereferenced copy of the release schema has `"array"` in its `type` and if any of the following are also true:

                  {
                    "deprecated": {
                      "description": "The single amendment object has been deprecated in favour of including amendments in an amendments (plural) array.",
                      "deprecatedVersion": "1.1"
                    }
                  }

On this page